@@ -76,19 +76,19 @@ LockScreen::LockScreen()
     if (orientation == "landscape"){
         m_View->setAttribute(Qt::WA_Maemo5LandscapeOrientation);
         m_WasPortrait = false;
-        LsWidget::setPortrait(false);
+        //LsWidget::setPortrait(false);
     } else if (orientation == "portrait"){
         m_View->setAttribute(Qt::WA_Maemo5PortraitOrientation);        
         m_WasPortrait = false;
-        LsWidget::setPortrait(true);
+        //LsWidget::setPortrait(true);
     }else{
         m_View->setAttribute(Qt::WA_Maemo5AutoOrientation);
-        conn.connect("",
+        /*conn.connect("",
                      MCE_SIGNAL_PATH,
                      MCE_SIGNAL_IF,
-                     MCE_DEVICE_ORIENTATION_SIG, this, SLOT(onOrientationChanged(QDBusMessage)));
-
-        LsWidget::setPortrait(isPortrait());
+                     MCE_DEVICE_ORIENTATION_SIG, this, SLOT(onOrientationChanged(QDBusMessage)));*/
+        connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(onOrientationChanged(int)));
+        //LsWidget::setPortrait(isPortrait());
         m_WasPortrait = !LsWidget::isPortrait();
     }
 
@@ -97,10 +97,10 @@ LockScreen::LockScreen()
     QString orientation = QSettings().value("Main/Orientation", "auto").toString().toLower();
     if (orientation == "portrait"){
         m_WasPortrait = false;
-        LsWidget::setPortrait(true);
+        //LsWidget::setPortrait(true);
     }else{
         m_WasPortrait = false;
-        LsWidget::setPortrait(false);
+        //LsWidget::setPortrait(false);
     }
 #endif    
 
@@ -138,7 +138,8 @@ bool LockScreen::hide()
         return false;
 
     m_View->hide();
-    stopUpdate();
+    QTimer::singleShot(250, this, SLOT(stopUpdate()));
+    //stopUpdate();
     return true;
 }
 
@@ -151,7 +152,7 @@ bool LockScreen::show()
     m_View->showFullScreen();    
 #else
     m_View->show();
-#endif
+#endif    
     setSizeAndPosition();
     m_View->update(m_View->rect());
     return true;
@@ -190,6 +191,10 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsNotification(name);
     else if (type == "Text")
         return new LsText(name);
+    else if (type == "Weather")
+        return new LsWeather(name);
+    else if (type == "Wifi")
+        return new LsWifi(name);
     return NULL;
 }
 
@@ -250,8 +255,10 @@ void LockScreen::onDisplayStateChangedSlot(QString displayState)
             show();
         stopUpdate();
     }else if (displayState == QLatin1String(MCE_DISPLAY_ON_STRING)) {
-        if (m_tklockState == MCE_TK_LOCKED && !m_isDialogActive){
-            //onOrientationChanged(0);
+        if (m_tklockState == MCE_TK_LOCKED && !m_isDialogActive){            
+            //LsWidget::setPortrait(isPortrait());
+            //setSizeAndPosition();
+            onOrientationChanged(0);
             startUpdate();            
         }
     }
@@ -330,14 +337,14 @@ void LockScreen::stopUpdate()
 }
 
 #ifdef Q_WS_MAEMO_5
-void LockScreen::onOrientationChanged(QDBusMessage msg)
+void LockScreen::onOrientationChanged(int)
+//void LockScreen::onOrientationChanged(QDBusMessage msg)
 {
-    QVariant val = msg.arguments()[0];
+    /*QVariant val = msg.arguments()[0];
     qDebug() << "onOrientationChanged:" << val.toString();
     if (val.toString() != "portrait" && val.toString() != "landscape")
         return;
-    LsWidget::setPortrait(val.toString() == "portrait");
-
+    LsWidget::setPortrait(val.toString() == "portrait");*/
     if (!m_View->isVisible())
         return;
 
@@ -352,6 +359,8 @@ void LockScreen::setSizeAndPosition()
         m_WasPortrait = isPortrait;
 
         qDebug() << "Orientation changed portrait=" << isPortrait;
+        setBackground();
+
         if (isPortrait){
             m_Scene.setSceneRect(0, 0, 480, 800);        
             m_View->setFixedSize(480, 800);
@@ -359,7 +368,6 @@ void LockScreen::setSizeAndPosition()
             m_Scene.setSceneRect(0, 0, 800, 480);
             m_View->setFixedSize(800, 480);
         }
-        setBackground();
 
         foreach(QGraphicsItem* item, m_Scene.items()){
             LsWidget* w = dynamic_cast<LsWidget*>(item);
@@ -393,7 +401,7 @@ bool LockScreen::isLocked()
     return res;
 }
 
-bool LockScreen::isPortrait()
+/*bool LockScreen::isPortrait()
 {
     bool res = false;
 #ifdef Q_WS_MAEMO_5
@@ -412,3 +420,4 @@ bool LockScreen::isPortrait()
 #endif
     return res;
 }
+*/
