@@ -77,7 +77,13 @@ int main(int argc, char *argv[])
         QFile::copy(":/DefaultSettings.conf", name);
 
     //Translation:
-    QString locale = QLocale::system().name();
+    QString locale = QSettings().value("Main/Locale", "").toString();
+    if (!locale.isEmpty()){
+        qDebug() << "Locale override:" << locale;
+        QLocale l(locale);
+        QLocale::setDefault(l);
+    }else
+        locale = QLocale::system().name();
     qDebug() << "Locale:" << locale;
     QTranslator translator;
     if (translator.load(QString("/opt/qtlockscreen/qtlockscreen_%1").arg(locale)))
