@@ -36,22 +36,20 @@ void LsDateTime::applySettings()
     m_DateColor = getColorSetting("DateColor", QColor(255,255,255));
 
     m_DateFormat = getSetting("DateFormat", "dd/MM/yyyy").toString();
-    m_TimeFormat = getSetting("TimeFormat", "hh:mm:ss").toString();
+    m_TimeFormat = getSetting("TimeFormat", "hh:mm").toString();
     if (m_TimeFormat.contains("s"))
         m_Timer.setInterval(500);
     else
         m_Timer.setInterval(2000);
 
-    m_TimeFont = QFont();
-    m_TimeFont.setPointSize(getSetting("TimeFontSize", 20).toInt());
+    m_TimeFont = getFontSetting("TimeFont", QFont("", 30, QFont::Normal, false));
 
     QFontMetrics fm(m_TimeFont);
     QSize size = fm.size(Qt::TextSingleLine, now.toString(m_TimeFormat));
 
     QRectF defSize(0,0, size.width(), size.height() + MINIMUM_TEXT_MARGIN);
 
-    m_DateFont = QFont();
-    m_DateFont.setPointSize(getSetting("DateFontSize", 15).toInt());
+    m_DateFont = getFontSetting("DateFont", QFont("", 12, QFont::Normal, false));
     fm = QFontMetrics(m_DateFont);
     size = fm.size(Qt::TextSingleLine, now.toString(m_DateFormat));
     defSize.setHeight(defSize.height() + size.height());
