@@ -17,6 +17,7 @@
 //    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "lsslidetounlock.h"
 #include <QApplication>
+#include "lockscreen.h"
 
 LsSlideToUnlock::LsSlideToUnlock(QString name) :
         LsWidget(name.isEmpty() ? "SlideToUnlock": name)
@@ -73,6 +74,9 @@ void LsSlideToUnlock::onSliderMoved(QPointF pos)
     #ifdef Q_WS_MAEMO_5
         QDBusInterface lockScreen("com.nokia.mce", "/com/nokia/mce/request", "com.nokia.mce.request", QDBusConnection::systemBus(), this);
         lockScreen.call("req_tklock_mode_change", "unlocked");
+        m_Slider->setPos(m_SliderInitialPos);
+        if (LockScreen::Debug)
+            qApp->quit();
     #else
         qApp->quit();
     #endif
