@@ -70,7 +70,7 @@ protected:
     void setSize(QSize);
 
 private:
-    static bool m_Portrait;
+    //static bool m_Portrait;
 
     QString m_Name;
     QRectF m_Size;
