@@ -35,5 +35,7 @@
 #include "lsnotification.h"
 #include "lsslidetounlock.h"
 #include "lstext.h"
+#include "lsweather.h"
+#include "lswifi.h"
 
 #endif // LSWIDGETS_H
